function out = max2(A,dim)
% MAX2 finds the first maximum value of a bidimensional matrix and its indices
%
% [row, column, value] = max2(A)
% OUT = max2(A,k)
% 
% [row, column, value] = max2(A)
% returns a vector having as the first element the row index, 
% as the second the column index
% and as the third the maximum value of A.
%
% If there are several identical maximum values, 
% the parameters of the first one found is returned.
%
% OUT = max2(A,dim)
% returns the row (if dim = 1) or column index (if dim = 2)
% of the maximum element in A along the dim dimension.
% If dim is 3, the maximum value of A is returned.
% 
%
% MAX2 differes from the Matlab MAX function insofar as  
% it gives access to the three parameters in one step
% rather than having to compute them separately in three steps.
%
% Vlad Atanasiu - 06/02/2002
% Revisions: 2  > 11/02/2002

[val,row] = max(A);
[val,col] = max(val);
%if nargin == 1 | (dim ~= 1 & dim ~= 2 & dim ~= 3)
if nargin == 1
	row = row(col);
	val = A(row,col);
	out = [row,col,val];
else
    switch dim
        case 1
		    out = row(col);
        case 2
		    out = col;
        otherwise
			row = row(col);
			out = A(row,col);
    end
end
